package meerkat.bulletinboard;

import meerkat.crypto.DigitalSignature;
import meerkat.protobuf.BulletinBoardAPI.BeginBatchMessage;
import meerkat.protobuf.BulletinBoardAPI.BatchData;
import meerkat.protobuf.Crypto.Signature;

import java.security.InvalidKeyException;
import java.security.SignatureException;
import java.security.cert.CertificateException;
import java.util.List;

/**
 * Created by Arbel Deutsch Peled on 20-Dec-15.
 * Extends the DigitalSignature interface with methods for signing and authenticating Batch messages
 */
public interface BatchDigitalSignature extends DigitalSignature {

    /**
     * Appends the batch data to the signed content (ignoring the signature)
     * @param completeBatch contains all the data about the batch
     * @throws SignatureException
     */
    public void updateContent(CompleteBatch completeBatch) throws SignatureException;

    /**
     * Performs a complete verification process on the given batch message
     * @param completeBatch contains the batch data as well as the signature
     * @return TRUE if the batch is verified and FALSE otherwise
     * @throws SignatureException | SignatureException | InvalidKeyException when underlying methods do so
     */
    public boolean verify(CompleteBatch completeBatch) throws SignatureException, CertificateException, InvalidKeyException;

}
